package assets

import (
	"bytes"
	_ "embed"
	"image"
	"image/color"
	"image/draw"
	_ "image/png"

	"github.com/hajimehoshi/ebiten/v2"
)

func LoadSprite() *ebiten.Image {
	m, _, err := image.Decode(bytes.NewReader(data))
	if err != nil {
		return ebiten.NewImageFromImage(Checkerboard(25, 32, 4))
	}

	return ebiten.NewImageFromImage(m)
}

func Checkerboard(w, h, cells int) image.Image {
	m := image.NewRGBA(Rect(0, 0, w, h))
	cellW, cellH := w/cells, h/cells
	for i := 0; i < cells; i++ {
		for j := 0; j < cells; j++ {
			c := color.RGBA{R: 255, B: 254, A: 255}
			if (i+j)%2 == 0 {
				c = color.RGBA{A: 255}
			}
			draw.Draw(m, Rect(i*cellW, j*cellH, cellW, cellH), &image.Uniform{C: c}, image.Point{}, draw.Src)
		}
	}
	return m
}

func Rect(x, y, w, h int) image.Rectangle {
	return image.Rect(x, y, x+w, y+h)
}

var data = []byte("\x89PNG\r\n\x1a\n\x00\x00\x00\rIHDR\x00\x00\x00&\x00\x00\x00&\b\x06\x00\x00\x00\xa8=\xe9\xae\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x04{IDATX\x85\xed\x98_L[U\x1c\xc7?%(\xb2\x8d!\x84\xb4\tA+\xa9\x8e\x04\v/X\x98\x01a\xcc\xd4`g\xd6\x17\x12g\xe0E1\xc6\xec\xc5a\"\xbaiFf\f0\x12\xf9\x97\x8c\x87%\xe8\vD!{\x818B@qa[̆3aC\x12'M\xd7\x05\x89\xad\fܚH\xea\"ׇ\xf6ܞ{{[\xb8\xc4\rc\xfc&M\xce9\xf7\x9c\xfb\xfb\xdc\xef\xefw\xcem\v\xff\xeb?\"\xcbf\x13z].\xb5m\xdb\xf7\x18G\x86.b\xb3;\x143A\x82\x01\x9f\xe5LM\x19\xa1\xb5\xfb\x00\xe4fd\xf0\xce\xec\xec\xf6\xc1d(\x80\xb6Ъ\x02p\xa1ùe\xa8ɮe\xdaB\xab\x00\xbc\x9d\xbd\xdb\"\xc0\x80\x94p\x86`2PN\xc1\xa3\x00\xbc\xf7ï\xca\tk./\xbd\x9b\xaf\x99\xdb\xf3\xcc\x1d\xb5\xfd\xfag04\xbdB\xc3\xc1\xbc\x84{\x0eM\xaf0\xb2\x1eu\xac\xdb]n\xf9mnQ\xbdf\x04\x98\x9e\x8cX\xb8C(\xda?a\xcdM6u\xcb\x12\xf7h\x9e\xba\xaa\xc4\xfaI3\x96\x00\xd6\xebr\xd1\x16ZU\xf4 z\xa7^\xcdX\x8f6n\xef\xe2\xf9'\xff\xa0\xbe5B8v\xed\xf37\xe2\xf3\xea[#\xf1\xf67=\xd1Ƌǀ\xf8\xc3\xf7\xba\\\x16\xbdk\t\xc46\xbbC\x93\xb2\xa5\xc1e\x00\xc6|a\x0e;\xb2\x00(h\xcc\xe7\xf0\xb7\xdf\x03p\xf0\xadBu\xed\xc9}\xa7\xf9\xf8\xe6\xfb|w{\x97:\xf6\xe9\xc0\x1a\x00\xc5_\xf4\xa8c\xf7\xcew\xaamQ\x83\xc1\x80Oâ:f\xb3;\xf4\x8c*\x94\xd1x?Q\xf0s\xd2\xf8\xcb_\x9fb}¯\x99\x9be/䉎ӆ\xf7\x91%\xc7\x0f\x06|\xa4\x89N\xcd\xfe=\x04\x03\xbeMo\xa0\xd7\xf4Y?\xd3g\xfdԷF\x18\x8ed\xd2\xffK>c\xb5ϩ\x1f#\xa8\xbd\x87ZX\x1a\\f\xef\xa1\x16@\xad=%\x18\xf0Q\xb3\u007f\x0f 962<\x87\xcd\xeeP\xa6F\xc7I_?\x06\xb7\xa2)K\xe6\x9aP\xddL\x96\x9ab#-\xbc\x16\xad'})\xc8r\xf7\xe5Q\x9b9\x88\xdb\xebQF\x86\xe7,@\xdc1\x9bݡL\xb4W\xa8\x93\xef\\Ժ\xf7tV\xf2\xe0\x00Y\xf6\f\x96\x06\x97\x13\x82&SAc>\xf7\xcewr\xa0yC\x1d\x9bh\xafP\x0f\xef\x84]\xf9\xd7\xc2)\xd2\v\xe3p\x05\x8d\xb1\xdcǜ\x93\x8b\x18\xa0@*\xe4\xec\x17\x8c\x01\x00\x8e\x1a\xc0\xfd\xa9,i\xe2\xcaҀ\xd5\x1d\xbf\xc2D{\x05\x11\u007f\x0e\xd7fW\x00(C8\x97\x99\x00e\xa4ɮe\x8a\xad\x89`\xb2DyX\x1b`\x83\"\"\xfex|\xa14y\xc1\xd4\xe8\xb8\xe6\xe2\xc3T\xdd\xf1+L\x8d\x8e\xab}\x8dc\x03\xf3kL\x8d\x8e\xe3\xf6z\x98h\xaf`\xa6\xfbg\xae\xcdf\x02\xb0\x18\x0e3V\xde\xc4\aW\a\x00\xedY$k1\x1c\xa6\xd8\x1a\xaf\xc7%\x83\x12X\xe8\x8an\x88<\x8a4P\x03\xf3k\xc6`z\x1dh\xde\xe0Bw\xd4\xd47O\xee\x06\xe0\\\xec\xd4\x16\a\xb0\xa8\x131\x0f`!\xf6\x1a+s\xad\xabc\x1d\xe5M\xea\x06r\xf7Eߥ\x11\xbf1\x14H'\xbf8*Ą/?l\x00\xe2\xef7w_\x1e\xf7\xfd!ua\xde+}\x00\xdc\xfd\xf1\x93T\xcfF\xf6\xb3\x1f\xa9\xed\xd0Wg\x00m-\xc91\x9b\x9c9\xb8\xbd\x1e\x82\x01\x9f%\x01Lh`~M\x9d(k\xb2\xfdq\x1e)\xb4b\xa4\x88?G\xd3\xcf(\x8c\xbbP{\xe4\xa6暈%\xe2\b\t\xb0\x94\xa9\x145'+\n\xfa{\xaae\x86\xd2\xdfG\x9f:\xbd\x92\x82\x89\xa7h鿕2\xc0V\xa5\a\x91]2\x05&\xd4y\xf4\xa9\x94\x01R駙\xbb\x00\x14Ugo\nb\x1aL/S\x01L\xc2\xc8R\xf7x\xa9\xb3Ģ/\xf4\x87-\xb7\xd7C\xa9\xb3D\xfb\x12\xbf>\u007fc\xe7\x88$\t\x8e4\xdd\xf8\x8e\xb9\x16\x8b\xab\x1e_z0\xd8\x018=TBG(\xf65W\xd9\xeeѰ\x1d(\xfd\xb7g#\xc7\b\x06|TWV=p\xe7\x92AA\x8a_\xe26\xbb\x83\xea\xca*f._R`\xfb\ak\n\xa0\xa4P\x9b\x82\x01\x94:K\x00\xb8>\u007fC\xf3\u007f\x85\x19P\xbd\xf3\xa5\xce\x12\x8b\xd8}\xa6\xc1\xf4\x80H5g6\xc5\xf2C\xa4J\x9f,\xd3'\xbf>Ѓ\x92a\xf1\x1b\xe9\x9f\xd8\fn\xaf\x87\xeaʪM\xb3\x04[H\xa5\x90\xbc\x19\xb6\xe3\x98|Vm凵\xe9T\x06\x03>\x8b\xdb\xeb1\xf5\xc7\x1dD\x1d\x9f\xb9|\xc9\xec\xb2\u007f\x9f\xfe\x06_\xb0\u0087\xc2\xf5}\x02\x00\x00\x00\x00IEND\xaeB`\x82")
